package com.xkrs.controller;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.dao.EmailEventDao;
import com.xkrs.model.entity.EmailEventEntity;
import com.xkrs.model.qo.EmailEventQo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Locale;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

@RestController
public class EmailEventController {

    public static Logger log = LoggerFactory.getLogger(EmailEventController.class);
    private final Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private EmailEventDao emailEventDao;

    @PostMapping("/add_email_event")
    public String addEmailEvent(@RequestBody EmailEventQo emailEventQo) {

        try {

            log.info("add_email_event 添加邮件事件：" + emailEventQo.toString());

            EmailEventEntity emailEventEntity = new EmailEventEntity();

            emailEventEntity.setEvent(emailEventQo.getEvent());
            emailEventEntity.setEmail(emailEventQo.getEmail());
            emailEventEntity.setLink(emailEventQo.getLink());
            emailEventEntity.setBulkId(emailEventQo.getBulkId());
            emailEventEntity.setTimestamp(emailEventQo.getTimestamp());
            emailEventEntity.setReason(emailEventQo.getReason());
            emailEventEntity.setBounceType(emailEventQo.getBounceType());
            emailEventEntity.setUsername(emailEventQo.getUsername());
            emailEventEntity.setFrom(emailEventQo.getFrom());
            emailEventEntity.setFromDomain(emailEventQo.getFromDomain());
            emailEventEntity.setTemplateId(emailEventQo.getTemplateId());
            emailEventEntity.setUseragent(emailEventQo.getUseragent());
            emailEventEntity.setSubject(emailEventQo.getSubject());
            emailEventEntity.setMessageId(emailEventQo.getMessageId());
            emailEventEntity.setEventId(emailEventQo.getEventId());

            String eventId = emailEventQo.getEventId();
            if ("delivered".equals(eventId)) {
                emailEventEntity.setEventDesc("递送成功，收件人邮件服务商已接收此邮件");
            }
            if ("dropped".equals(eventId)) {
                emailEventEntity.setEventDesc("因为某种原因，这封邮件不能送达，被丢弃");
            }
            if ("bounce".equals(eventId)) {
                emailEventEntity.setEventDesc("收件人邮件服务商拒收此邮件(一般是因为邮箱地址错误)");
            }
            if ("open".equals(eventId)) {
                emailEventEntity.setEventDesc("收件人打开了此邮件");
            }
            if ("click".equals(eventId)) {
                emailEventEntity.setEventDesc("收件人点击了此邮件中的链接");
            }
            if ("spamreport".equals(eventId)) {
                emailEventEntity.setEventDesc("收件人举报了此邮件");
            }
            if ("unsubscribe".equals(eventId)) {
                emailEventEntity.setEventDesc("收件人点击了业务方的“退订”按钮，需要业务方在退订链接中包含unsubscribe关键词");
            }
            if ("deferred".equals(eventId)) {
                emailEventEntity.setEventDesc("邮件被收件人邮件服务商延迟传递，正在重试中");
            }

            emailEventDao.save(emailEventEntity);

            return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功", locale);

        } catch (Exception e) {
            e.printStackTrace();
            return outputEncapsulationObject(PromptMessageEnum.PROCESS_FAIL, "添加失败", locale);
        }

    }

}
